@@ -1,7 +1,7 @@
 from ekp_sdk.util.clean_null_terms import clean_null_terms
 
 
-def Div(children=None, class_name=None, style=None, when=None, context=None):
+def Div(children=None, class_name=None, style=None, when=None, context=None, background_url=None):
     return {
         "_type": "Div",
         "props": clean_null_terms({
@@ -9,6 +9,7 @@ def Div(children=None, class_name=None, style=None, when=None, context=None):
             "children": children or [],
             "style": style,
             "when": when,
-            "context": context
+            "context": context,
+            "backgroundUrl": background_url,
         })
     }
\ No newline at end of file
